==> graphql-auth-transformer-1.0.36.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

<a name="1.0.36"></a>
## [1.0.36](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.34...graphql-auth-transformer@1.0.36) (2019-01-08)


### Bug Fixes

* **amplify-cli:** manually patch version ([#674](https://github.com/aws-amplify/amplify-cli/issues/674)) ([0d6f039](https://github.com/aws-amplify/amplify-cli/commit/0d6f039))




<a name="1.0.34"></a>
## [1.0.34](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.34-beta.0...graphql-auth-transformer@1.0.34) (2018-12-20)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.34-beta.0"></a>
## [1.0.34-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.33...graphql-auth-transformer@1.0.34-beta.0) (2018-12-20)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.33"></a>
## [1.0.33](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.33-beta.0...graphql-auth-transformer@1.0.33) (2018-11-09)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.33-beta.0"></a>
## [1.0.33-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.33-beta.0) (2018-11-09)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.32"></a>
## [1.0.32](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.32-beta.0...graphql-auth-transformer@1.0.32) (2018-11-05)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.32-beta.0"></a>
## [1.0.32-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.32-beta.0) (2018-11-05)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.31"></a>
## [1.0.31](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.31) (2018-11-02)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.30"></a>
## [1.0.30](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.30-beta.0...graphql-auth-transformer@1.0.30) (2018-11-02)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.30-beta.0"></a>
## [1.0.30-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.30-beta.0) (2018-11-02)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.29"></a>
## [1.0.29](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.29-beta.0...graphql-auth-transformer@1.0.29) (2018-10-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.29-beta.0"></a>
## [1.0.29-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.29-beta.0) (2018-10-23)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.28"></a>
## [1.0.28](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.28-beta.0...graphql-auth-transformer@1.0.28) (2018-10-18)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.28-beta.0"></a>
## [1.0.28-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.28-beta.0) (2018-10-12)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.12"></a>
## [1.0.12](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.11...graphql-auth-transformer@1.0.12) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.11"></a>
## [1.0.11](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.10...graphql-auth-transformer@1.0.11) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.10"></a>
## [1.0.10](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.9...graphql-auth-transformer@1.0.10) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.9"></a>
## [1.0.9](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.8...graphql-auth-transformer@1.0.9) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.8"></a>
## [1.0.8](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.7...graphql-auth-transformer@1.0.8) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.7"></a>
## [1.0.7](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.6...graphql-auth-transformer@1.0.7) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.6"></a>
## [1.0.6](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.5...graphql-auth-transformer@1.0.6) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.5"></a>
## [1.0.5](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.4...graphql-auth-transformer@1.0.5) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.4"></a>
## 1.0.4 (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.3"></a>
## 1.0.3 (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.2"></a>
## 1.0.2 (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.1"></a>
## 1.0.1 (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

==> graphql-auth-transformer-2.0.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [2.0.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@2.0.0-multienv.2...graphql-auth-transformer@2.0.0) (2019-02-06)

**Note:** Version bump only for package graphql-auth-transformer





<a name="2.0.0-multienv.2"></a>
# [2.0.0-multienv.2](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.34-multienv.1...graphql-auth-transformer@2.0.0-multienv.2) (2018-12-31)


### Bug Fixes

* update grahql transformer package versions for multienv ([8b4b2bd](https://github.com/aws-amplify/amplify-cli/commit/8b4b2bd))




<a name="1.0.34-multienv.1"></a>
## [1.0.34-multienv.1](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.34-multienv.0...graphql-auth-transformer@1.0.34-multienv.1) (2018-12-19)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.34-multienv.0"></a>
## [1.0.34-multienv.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.33...graphql-auth-transformer@1.0.34-multienv.0) (2018-11-16)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.33"></a>
## [1.0.33](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.33-beta.0...graphql-auth-transformer@1.0.33) (2018-11-09)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.33-beta.0"></a>
## [1.0.33-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.33-beta.0) (2018-11-09)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.32"></a>
## [1.0.32](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.32-beta.0...graphql-auth-transformer@1.0.32) (2018-11-05)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.32-beta.0"></a>
## [1.0.32-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.32-beta.0) (2018-11-05)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.31"></a>
## [1.0.31](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.31) (2018-11-02)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.30"></a>
## [1.0.30](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.30-beta.0...graphql-auth-transformer@1.0.30) (2018-11-02)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.30-beta.0"></a>
## [1.0.30-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.30-beta.0) (2018-11-02)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.29"></a>
## [1.0.29](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.29-beta.0...graphql-auth-transformer@1.0.29) (2018-10-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.29-beta.0"></a>
## [1.0.29-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.29-beta.0) (2018-10-23)


### Bug Fixes

* **graphql-auth-transformer:** Modifies the name of the user pool resource ([d613481](https://github.com/aws-amplify/amplify-cli/commit/d613481))




<a name="1.0.28"></a>
## [1.0.28](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.28-beta.0...graphql-auth-transformer@1.0.28) (2018-10-18)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.28-beta.0"></a>
## [1.0.28-beta.0](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.12...graphql-auth-transformer@1.0.28-beta.0) (2018-10-12)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.12"></a>
## [1.0.12](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.11...graphql-auth-transformer@1.0.12) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.11"></a>
## [1.0.11](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.10...graphql-auth-transformer@1.0.11) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.10"></a>
## [1.0.10](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.9...graphql-auth-transformer@1.0.10) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.9"></a>
## [1.0.9](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.8...graphql-auth-transformer@1.0.9) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.8"></a>
## [1.0.8](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.7...graphql-auth-transformer@1.0.8) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.7"></a>
## [1.0.7](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.6...graphql-auth-transformer@1.0.7) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.6"></a>
## [1.0.6](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.5...graphql-auth-transformer@1.0.6) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.5"></a>
## [1.0.5](https://github.com/aws-amplify/amplify-cli/compare/graphql-auth-transformer@1.0.4...graphql-auth-transformer@1.0.5) (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.4"></a>
## 1.0.4 (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.3"></a>
## 1.0.3 (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.2"></a>
## 1.0.2 (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer

<a name="1.0.1"></a>
## 1.0.1 (2018-08-23)




**Note:** Version bump only for package graphql-auth-transformer
